@@ -10,12 +10,14 @@ O = t(matrix(
     0, 0, 0, 0, 0,
     0, 0, 0, 0, 0,
     0, 0, 0, 0, 0,
-    0, 0, 0, 0, 0), 5, 5)); O=O+t(O)
-graphID(L,O)
+    0, 0, 0, 0, 0), 5, 5)); O = O + t(O)
+g = MixedGraph(L,O) # Create graph
+g$plot() # Plot grapth
+semID(g) # Test for global/generic identifiability
+readline("Press any key to continue to next example")
 
 
 ## Ex. 3a HTC id
-
 L = t(matrix(
   c(0, 1, 0, 0, 0,
     0, 0, 1, 0, 0,
@@ -27,8 +29,11 @@ O = t(matrix(
     0, 0, 0, 1, 1,
     0, 0, 0, 0, 0,
     0, 0, 0, 0, 0,
-    0, 0, 0, 0, 0), 5, 5)); O=O+t(O)
-graphID(L,O)
+    0, 0, 0, 0, 0), 5, 5)); O = O + t(O)
+g = MixedGraph(L,O) # Create graph
+g$plot() # Plot grapth
+semID(g) # Test for global/generic identifiability
+readline("Press any key to continue to next example")
 
 
 ## Ex 3b HTC id
@@ -44,12 +49,14 @@ O = t(matrix(
     0, 0, 0, 0, 0,
     0, 0, 0, 0, 0,
     0, 0, 0, 0, 0,
-    0, 0, 0, 0, 0), 5, 5)); O=O+t(O)
-graphID(L,O)
+    0, 0, 0, 0, 0), 5, 5)); O = O + t(O)
+g = MixedGraph(L,O) # Create graph
+g$plot() # Plot grapth
+semID(g) # Test for global/generic identifiability
+readline("Press any key to continue to next example")
 
 
 ## Ex 3c HTC inc
-
 L = t(matrix(
   c(0, 1, 1, 1, 0,
     0, 0, 0, 0, 0,
@@ -61,12 +68,14 @@ O = t(matrix(
     0, 0, 0, 0, 0,
     0, 0, 0, 0, 0,
     0, 0, 0, 0, 0,
-    0, 0, 0, 0, 0), 5, 5)); O=O+t(O)
-graphID(L,O)
+    0, 0, 0, 0, 0), 5, 5)); O = O + t(O)
+g = MixedGraph(L,O) # Create graph
+g$plot() # Plot grapth
+semID(g) # Test for global/generic identifiability
+readline("Press any key to continue to next example")
 
 
 ## Ex 3d HTC id
-
 L = t(matrix(
   c(0, 1, 0, 0, 0,
     0, 0, 1, 0, 0,
@@ -78,11 +87,13 @@ O = t(matrix(
     0, 0, 0, 0, 0,
     0, 0, 0, 1, 0,
     0, 0, 0, 0, 0,
-    0, 0, 0, 0, 0), 5, 5)); O=O+t(O)
-graphID(L,O)
+    0, 0, 0, 0, 0), 5, 5)); O = O + t(O)
+g = MixedGraph(L,O) # Create graph
+g$plot() # Plot grapth
+semID(g) # Test for global/generic identifiability
+readline("Press any key to continue to next example")
 
 ## Ex 3e HTC inc
-
 L = t(matrix(
   c(0, 1, 0, 0, 0,
     0, 0, 1, 0, 0,
@@ -94,12 +105,14 @@ O = t(matrix(
     0, 0, 1, 1, 0,
     0, 0, 0, 0, 0,
     0, 0, 0, 0, 1,
-    0, 0, 0, 0, 0), 5, 5)); O=O+t(O)
-graphID(L,O)
+    0, 0, 0, 0, 0), 5, 5)); O = O + t(O)
+g = MixedGraph(L,O) # Create graph
+g$plot() # Plot grapth
+semID(g) # Test for global/generic identifiability
+readline("Press any key to continue to next example")
 
 
 ## Ex 4a HTC nonid
-
 L = t(matrix(
   c(0, 1, 1, 1, 1,
     0, 0, 1, 1, 0,
@@ -111,12 +124,14 @@ O = t(matrix(
     0, 0, 1, 0, 1,
     0, 0, 0, 0, 0,
     0, 0, 0, 0, 0,
-    0, 0, 0, 0, 0), 5, 5)); O=O+t(O)
-graphID(L,O)
+    0, 0, 0, 0, 0), 5, 5)); O = O + t(O)
+g = MixedGraph(L,O) # Create graph
+g$plot() # Plot grapth
+semID(g) # Test for global/generic identifiability
+readline("Press any key to continue to next example")
 
 
 ## Ex 4b HTC inc
-
 L = t(matrix(
   c(0, 1, 1, 1, 1,
     0, 0, 1, 0, 0,
@@ -128,12 +143,14 @@ O = t(matrix(
     0, 0, 0, 0, 0,
     0, 0, 0, 0, 0,
     0, 0, 0, 0, 0,
-    0, 0, 0, 0, 0), 5, 5)); O=O+t(O)
-graphID(L,O)
+    0, 0, 0, 0, 0), 5, 5)); O = O + t(O)
+g = MixedGraph(L,O) # Create graph
+g$plot() # Plot grapth
+semID(g) # Test for global/generic identifiability
+readline("Press any key to continue to next example")
 
 
 ## Ex 4c HTC nonid
-
 L = t(matrix(
   c(0, 1, 1, 0, 0,
     1, 0, 0, 0, 0,
@@ -145,12 +162,14 @@ O = t(matrix(
     0, 0, 0, 0, 0,
     0, 0, 0, 0, 0,
     0, 0, 0, 0, 0,
-    0, 0, 0, 0, 0), 5, 5)); O=O+t(O)
-graphID(L,O)
+    0, 0, 0, 0, 0), 5, 5)); O = O + t(O)
+g = MixedGraph(L,O) # Create graph
+g$plot() # Plot grapth
+semID(g) # Test for global/generic identifiability
+readline("Press any key to continue to next example")
 
 
 ## Ex 4d HTC inc
-
 L = t(matrix(
   c(0, 0, 0, 1, 1,
     0, 0, 1, 0, 1,
@@ -162,12 +181,14 @@ O = t(matrix(
     0, 0, 0, 0, 0,
     0, 0, 0, 0, 0,
     0, 0, 0, 0, 1,
-    0, 0, 0, 0, 0), 5, 5)); O=O+t(O)
-graphID(L,O)
+    0, 0, 0, 0, 0), 5, 5)); O = O + t(O)
+g = MixedGraph(L,O) # Create graph
+g$plot() # Plot grapth
+semID(g) # Test for global/generic identifiability
+readline("Press any key to continue to next example")
 
 
 ## Ex 5a HTC inc
-
 L = t(matrix(
   c(0, 1, 1, 1, 1,
     0, 0, 0, 0, 1,
@@ -179,12 +200,14 @@ O = t(matrix(
     0, 0, 0, 0, 0,
     0, 0, 0, 0, 0,
     0, 0, 0, 0, 0,
-    0, 0, 0, 0, 0), 5, 5)); O=O+t(O)
-graphID(L,O)
+    0, 0, 0, 0, 0), 5, 5)); O = O + t(O)
+g = MixedGraph(L,O) # Create graph
+g$plot() # Plot grapth
+semID(g) # Test for global/generic identifiability
+readline("Press any key to continue to next example")
 
 
 ## Ex 5b HTC inc
-
 L = t(matrix(
   c(0, 1, 0, 1, 1,
     0, 0, 1, 0, 1,
@@ -196,12 +219,14 @@ O = t(matrix(
     0, 0, 0, 1, 0,
     0, 0, 0, 0, 0,
     0, 0, 0, 0, 0,
-    0, 0, 0, 0, 0), 5, 5)); O=O+t(O)
-graphID(L,O)
+    0, 0, 0, 0, 0), 5, 5)); O = O + t(O)
+g = MixedGraph(L,O) # Create graph
+g$plot() # Plot grapth
+semID(g) # Test for global/generic identifiability
+readline("Press any key to continue to next example")
 
 
 ## Ex 5c HTC inc
-
 L = t(matrix(
   c(0, 1, 0, 0, 0,
     0, 0, 1, 0, 0,
@@ -213,12 +238,14 @@ O = t(matrix(
     0, 0, 0, 0, 0,
     0, 0, 0, 0, 0,
     0, 0, 0, 0, 0,
-    0, 0, 0, 0, 0), 5, 5)); O=O+t(O)
-graphID(L,O)
+    0, 0, 0, 0, 0), 5, 5)); O = O + t(O)
+g = MixedGraph(L,O) # Create graph
+g$plot() # Plot grapth
+semID(g) # Test for global/generic identifiability
+readline("Press any key to continue to next example")
 
 
 ## Ex 5d HTC inc
-
 L = t(matrix(
   c(0, 1, 0, 1, 1,
     0, 0, 1, 0, 1,
@@ -230,12 +257,14 @@ O = t(matrix(
     0, 0, 0, 0, 0,
     0, 0, 0, 0, 0,
     0, 0, 0, 0, 0,
-    0, 0, 0, 0, 0), 5, 5)); O=O+t(O)
-graphID(L,O)
+    0, 0, 0, 0, 0), 5, 5)); O = O + t(O)
+g = MixedGraph(L,O) # Create graph
+g$plot() # Plot grapth
+semID(g) # Test for global/generic identifiability
+readline("Press any key to continue to next example")
 
 
 ## Ex 7a (Fig 9a)
-
 L = t(matrix(
   c(0, 1, 1, 0, 0,
     0, 0, 1, 1, 1,
@@ -247,5 +276,7 @@ O = t(matrix(
     0, 0, 1, 0, 1,
     0, 0, 0, 0, 0,
     0, 0, 0, 0, 0,
-    0, 0, 0, 0, 0), 5, 5)); O=O+t(O)
-graphID(L,O)
+    0, 0, 0, 0, 0), 5, 5)); O = O + t(O)
+g = MixedGraph(L,O) # Create graph
+g$plot() # Plot grapth
+semID(g) # Test for global/generic identifiability
